Index: /applications/editors/josm/plugins/o5m/src/org/openstreetmap/josm/plugins/o5m/io/O5mReader.java
===================================================================
--- /applications/editors/josm/plugins/o5m/src/org/openstreetmap/josm/plugins/o5m/io/O5mReader.java	(revision 34845)
+++ /applications/editors/josm/plugins/o5m/src/org/openstreetmap/josm/plugins/o5m/io/O5mReader.java	(revision 34846)
@@ -124,7 +124,7 @@
      * parse the input stream
      * @param source The InputStream that contains the OSM data in o5m format
-     * @throws O5mParsingCancelException if operation was canceled 
-     */
-    public void parse(InputStream source) throws O5mParsingCancelException {
+     * @throws ParsingCancelException if operation was canceled 
+     */
+    public void parse(InputStream source) throws ParsingCancelException {
         this.fis = new BufferedInputStream(source);
         is = fis;
@@ -143,10 +143,10 @@
     }
 
-    private void readFile() throws IOException, O5mParsingCancelException {
+    private void readFile() throws IOException, ParsingCancelException {
         boolean done = false;
         while (!done) {
             if (cancel) {
                 cancel = false;
-                throw new O5mParsingCancelException(tr("Reading was canceled at file offset {0}", countBytes));
+                throw new ParsingCancelException(tr("Reading was canceled at file offset {0}", countBytes));
             }
             is = fis;
@@ -653,8 +653,8 @@
      * Exception thrown after user cancellation.
      */
-    private static final class O5mParsingCancelException extends Exception implements ImportCancelException {
+    private static final class ParsingCancelException extends Exception implements ImportCancelException {
         private static final long serialVersionUID = 1L;
 
-        O5mParsingCancelException(String msg) {
+        ParsingCancelException(String msg) {
             super(msg);
         }
@@ -685,17 +685,15 @@
         progressMonitor.addCancelListener(cancelListener);
         try {
-            progressMonitor.beginTask(tr("Prepare OSM data..."), 3); // read, prepare, render
+            progressMonitor.beginTask(tr("Prepare OSM data..."), 3); // read, prepare, create data layer
             progressMonitor.indeterminateSubTask(tr("Reading OSM data..."));
 
             parse(source);
             progressMonitor.worked(1);
-            
             progressMonitor.indeterminateSubTask(tr("Preparing data set..."));
             prepareDataSet();
             progressMonitor.worked(1);
             if (cancel) { 
-                throw new O5mParsingCancelException(tr("Import was canceled while preparing data"));
-            }
-            progressMonitor.indeterminateSubTask(tr("Rendering data set..."));
+                throw new ParsingCancelException(tr("Import was canceled"));
+            }
             return getDataSet();
         } catch (IllegalDataException e) {
